<?php
/********************************************************************
 * NotFTP v1.2.2 by Ryan Grove (ryan@wonko.com)
 * Copyright (c) 2002 Ryan Grove. All rights reserved.
 *
 * This script is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA
 ********************************************************************/

include_once("config.php");

$debug = false; // Set to true to display debugging information (duh)

//
// string getMIMEType(string filename)
//   Attempts to determine the MIME type of a file based
//   on its extension, using the standard MIME type
//   registry from the IANA. If the MIME type can't be
//   determined, returns "text/plain".
//
function getMIMEType($file)
{
    global $mimetypes;

    // Get the extension
    $pos = strrpos($file, ".");

    if ($pos !== false)
        $ext = substr($file, $pos + 1);
    else
        return "text/plain";

    // Find this extension in our MIME type array
    foreach($mimetypes as $mime)
    {
        if (eregi($ext, $mime))
        {
            prev($mimetypes);
            return key($mimetypes);
        }
    }

    // No MIME type found, return text/plain
    return "text/plain";
}

//
// array rawlist2nlist(array list)
//   Converts the output of ftp_rawlist() to an array that
//   is structured similarly to the output of ftp_nlist().
//
function rawlist2nlist($list)
{
    $newlist = array();
    @reset($list);

    while (list(,$row) = @each($list))
    {
        $index = strrpos($row, " ");
        $newlist[] = substr($row, $index+1);
    }

    return $newlist;
}

//
// bool isdir(string item)
//   Given an entry from the output of ftp_rawlist(),
//   attempts to determine whether the entry is a
//   directory. Returns true for a directory, false
//   otherwise.
//
function isdir($item)
{
    global $systype;

    // some rawlists returned by ftp_rawlist() contain '.' and '..' directory
    // so we ignore them, even they have the 'd' permisson on
    if (eregi("windows", $systype))
    {
        if (ereg("^d[rtwx\-]{9}", $item))
            return true;
        else
            return false;
    }
    else
    {
        if (ereg("^d[rstwx\-]{9}", $item))
            return true;
        else
            return false;
    }
}

//
// bool isfile(string item)
//   Given an entry from the output of ftp_rawlist(),
//   attempts to determine whether the entry is a
//   file. Returns true for a file, false
//   otherwise.
//
function isfile($item)
{
    if (ereg("^[rtwxs\-]{10}", $item))
        return true;
    else
        return false;
}

//
// string getFileDate(string item)
//   Given an entry from the output of ftp_rawlist(),
//   attempts to return the date of the file or directory.
//
function getFileDate($item)
{
    global $conn;

//  this sometimes slows down quite a lot
//    $time = @ftp_mdtm($conn, getName($item));

//    if ($time > 0)
//    {
//        return date("H:i M d, Y", $time);
//    }
//    else
//    {
        $matches = array();
        eregi("([a-z]{3} +[0-9]{1,2} [ 0-9\:]{4,5})", $item, $matches);

        return $matches[1];
//    }
}

//
// string getName(string item)
//   Given an entry from the output of ftp_rawlist(),
//   attempts to return the name of the file or
//   directory.
//
function getName($item)
{
    $matches = array();
    eregi("[a-z]{3} +[0-9]{1,2} [ 0-9\:]{4,5} (.+)$", $item, $matches);

    return $matches[1];
}

//
// string getPermissions(string item)
//   Given an entry from the output of ftp_rawlist(),
//   attempts to return the permissions of the item.
//
function getPermissions($item)
{
    $matches = array();

    eregi("^(.{10}) ", $item, $matches);
    return $matches[1];
}

//
// int getSize(string item)
//   Given a file entry from the output of ftp_rawlist(),
//   attempts to return the size of the file in bytes.
//
function getSize($item)
{
    $matches = array();
    eregi("^.{10}[ ]+[0-9]+ [^ ]+ +[^ ]+ +([0-9]+) ", $item, $matches);

    return $matches[1];
}

//
// int getOwner(string item)
//   Given a file entry from the output of ftp_rawlist(),
//   attempts to return the owner of the file
//
function getOwner($item)
{
    $matches = array();
    eregi("^.{10}[ ]+[0-9]+ ([^ ]+) ", $item, $matches);

    return $matches[1];
}

//
// int getGroup(string item)
//   Given a file entry from the output of ftp_rawlist(),
//   attempts to return the group of the file
//
function getGroup($item)
{
    $matches = array();
    eregi("^.{10}[ ]+[0-9]+ [^ ]+ +([^ ]+) ", $item, $matches);

    return $matches[1];
}

//
// bool recurseDelete(string dir)
//   Attempts to delete a directory and its contents recursively.
//   Returns true on success, false on failure.
//
function recurseDelete($dir)
{
    global $systype, $conn;

    $rawlist=ftp_rawlist($conn, $dir);

    foreach ($rawlist as $item)
    {
        // if it's a file, delete it
        if (isfile($item))
        {
            if (!@ftp_delete($conn, $dir."/".getName($item)))
            {
                return false;
            } // can't delete
        }

        // if it's a directory, then recurse
        if (isdir($item))
        {
            if (!(recurseDelete($dir."/".getName($item))))
            {
                return false;
            } // can't delete
        }
    }

    // now remove the directory itself
    if (!@ftp_rmdir($conn, $dir))
    {
        return false;
    } // can't remove

    return true;
}

?>
